VoidKind

Enum VoidKind 

pub enum VoidKind {
Show 26 variants Doc, Para, ThematicBreak, Section, Div, BlockQuote, DefinitionList, Table, ListItem, DefinitionListItem, Term, Definition, Caption, SoftBreak, HardBreak, NonBreakingSpace, Emph, Strong, Span, Mark, Superscript, Subscript, Insert, Delete, DoubleQuoted, SingleQuoted,
}
The void-payload node kinds, addable via Builder::add. Kinds with a payload have their own dedicated add_* method instead.

Variants



Doc



Para



ThematicBreak



Section



Div



BlockQuote



DefinitionList



Table



ListItem



DefinitionListItem



Term



Definition



Caption



SoftBreak



HardBreak



NonBreakingSpace



Emph



Strong



Span



Mark



Superscript



Subscript



Insert



Delete



DoubleQuoted



SingleQuoted